# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.social_sign_in_request import SocialSignInRequest

class TestSocialSignInRequest(unittest.TestCase):
    """SocialSignInRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SocialSignInRequest:
        """Test SocialSignInRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SocialSignInRequest`
        """
        model = SocialSignInRequest()
        if include_optional:
            return SocialSignInRequest(
                callback_url = '',
                new_user_callback_url = '',
                error_callback_url = '',
                provider = '',
                disable_redirect = True,
                id_token = better_auth.models.social_sign_in_request_id_token.socialSignIn_request_idToken(
                    token = '', 
                    nonce = '', 
                    access_token = '', 
                    refresh_token = '', 
                    expires_at = 1.337, ),
                scopes = [
                    null
                    ],
                request_sign_up = True,
                login_hint = '',
                additional_data = ''
            )
        else:
            return SocialSignInRequest(
                provider = '',
        )
        """

    def testSocialSignInRequest(self):
        """Test SocialSignInRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
