# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.generate_passkey_registration_options200_response import GeneratePasskeyRegistrationOptions200Response

class TestGeneratePasskeyRegistrationOptions200Response(unittest.TestCase):
    """GeneratePasskeyRegistrationOptions200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeneratePasskeyRegistrationOptions200Response:
        """Test GeneratePasskeyRegistrationOptions200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeneratePasskeyRegistrationOptions200Response`
        """
        model = GeneratePasskeyRegistrationOptions200Response()
        if include_optional:
            return GeneratePasskeyRegistrationOptions200Response(
                challenge = '',
                rp = better_auth.models.generate_passkey_registration_options_200_response_rp.generatePasskeyRegistrationOptions_200_response_rp(
                    name = '', 
                    id = '', ),
                user = better_auth.models.generate_passkey_registration_options_200_response_user.generatePasskeyRegistrationOptions_200_response_user(
                    id = '', 
                    name = '', 
                    display_name = '', ),
                pub_key_cred_params = [
                    better_auth.models.generate_passkey_registration_options_200_response_pub_key_cred_params_inner.generatePasskeyRegistrationOptions_200_response_pubKeyCredParams_inner(
                        type = '', 
                        alg = 1.337, )
                    ],
                timeout = 1.337,
                exclude_credentials = [
                    better_auth.models.generate_passkey_registration_options_200_response_exclude_credentials_inner.generatePasskeyRegistrationOptions_200_response_excludeCredentials_inner(
                        id = '', 
                        type = '', 
                        transports = [
                            ''
                            ], )
                    ],
                authenticator_selection = better_auth.models.generate_passkey_registration_options_200_response_authenticator_selection.generatePasskeyRegistrationOptions_200_response_authenticatorSelection(
                    authenticator_attachment = '', 
                    require_resident_key = True, 
                    user_verification = '', ),
                attestation = '',
                extensions = None
            )
        else:
            return GeneratePasskeyRegistrationOptions200Response(
        )
        """

    def testGeneratePasskeyRegistrationOptions200Response(self):
        """Test GeneratePasskeyRegistrationOptions200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
