# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.passkey_api import PasskeyApi


class TestPasskeyApi(unittest.TestCase):
    """PasskeyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasskeyApi()

    def tearDown(self) -> None:
        pass

    def test_generate_passkey_registration_options(self) -> None:
        """Test case for generate_passkey_registration_options

        """
        pass

    def test_passkey_delete_passkey_post(self) -> None:
        """Test case for passkey_delete_passkey_post

        """
        pass

    def test_passkey_generate_authenticate_options(self) -> None:
        """Test case for passkey_generate_authenticate_options

        """
        pass

    def test_passkey_list_user_passkeys_get(self) -> None:
        """Test case for passkey_list_user_passkeys_get

        """
        pass

    def test_passkey_update_passkey_post(self) -> None:
        """Test case for passkey_update_passkey_post

        """
        pass

    def test_passkey_verify_authentication(self) -> None:
        """Test case for passkey_verify_authentication

        """
        pass

    def test_passkey_verify_registration(self) -> None:
        """Test case for passkey_verify_registration

        """
        pass


if __name__ == '__main__':
    unittest.main()
