# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.social_sign_in403_response import SocialSignIn403Response

class TestSocialSignIn403Response(unittest.TestCase):
    """SocialSignIn403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SocialSignIn403Response:
        """Test SocialSignIn403Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SocialSignIn403Response`
        """
        model = SocialSignIn403Response()
        if include_optional:
            return SocialSignIn403Response(
                message = ''
            )
        else:
            return SocialSignIn403Response(
        )
        """

    def testSocialSignIn403Response(self):
        """Test SocialSignIn403Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
