# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_account_info_get(self) -> None:
        """Test case for account_info_get

        """
        pass

    def test_change_email(self) -> None:
        """Test case for change_email

        """
        pass

    def test_change_password(self) -> None:
        """Test case for change_password

        """
        pass

    def test_delete_user(self) -> None:
        """Test case for delete_user

        """
        pass

    def test_delete_user_callback_get(self) -> None:
        """Test case for delete_user_callback_get

        """
        pass

    def test_error_get(self) -> None:
        """Test case for error_get

        """
        pass

    def test_forget_password(self) -> None:
        """Test case for forget_password

        """
        pass

    def test_get_access_token_post(self) -> None:
        """Test case for get_access_token_post

        """
        pass

    def test_get_session(self) -> None:
        """Test case for get_session

        """
        pass

    def test_link_social_account(self) -> None:
        """Test case for link_social_account

        """
        pass

    def test_list_user_accounts(self) -> None:
        """Test case for list_user_accounts

        """
        pass

    def test_list_user_sessions(self) -> None:
        """Test case for list_user_sessions

        """
        pass

    def test_ok_get(self) -> None:
        """Test case for ok_get

        """
        pass

    def test_refresh_token_post(self) -> None:
        """Test case for refresh_token_post

        """
        pass

    def test_reset_password(self) -> None:
        """Test case for reset_password

        """
        pass

    def test_reset_password_callback(self) -> None:
        """Test case for reset_password_callback

        """
        pass

    def test_revoke_other_sessions_post(self) -> None:
        """Test case for revoke_other_sessions_post

        """
        pass

    def test_revoke_session_post(self) -> None:
        """Test case for revoke_session_post

        """
        pass

    def test_revoke_sessions_post(self) -> None:
        """Test case for revoke_sessions_post

        """
        pass

    def test_send_verification_email(self) -> None:
        """Test case for send_verification_email

        """
        pass

    def test_sign_in_email(self) -> None:
        """Test case for sign_in_email

        """
        pass

    def test_sign_out(self) -> None:
        """Test case for sign_out

        """
        pass

    def test_sign_up_with_email_and_password(self) -> None:
        """Test case for sign_up_with_email_and_password

        """
        pass

    def test_social_sign_in(self) -> None:
        """Test case for social_sign_in

        """
        pass

    def test_unlink_account_post(self) -> None:
        """Test case for unlink_account_post

        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        """
        pass

    def test_verify_email_get(self) -> None:
        """Test case for verify_email_get

        """
        pass


if __name__ == '__main__':
    unittest.main()
