# coding: utf-8

# flake8: noqa

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.1-beta11"

# Define package exports
__all__ = [
    "AdminApi",
    "ApiKeyApi",
    "DefaultApi",
    "OneTapApi",
    "PasskeyApi",
    "StripeApi",
    "TwoFactorApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Account",
    "AccountInfoGet200Response",
    "AccountInfoGet200ResponseUser",
    "AdminBanUserRequest",
    "AdminCreateUserRequest",
    "AdminHasPermission200Response",
    "AdminHasPermissionRequest",
    "AdminListUserSessions200Response",
    "AdminListUserSessionsRequest",
    "AdminListUsers200Response",
    "AdminRevokeUserSessionRequest",
    "AdminSetUserPasswordRequest",
    "AdminSetUserRoleRequest",
    "AdminUpdateUserRequest",
    "ApiKeyCreatePost200Response",
    "ApiKeyCreatePostRequest",
    "ApiKeyDeletePost200Response",
    "ApiKeyDeletePostRequest",
    "ApiKeyGetGet200Response",
    "ApiKeyListGet200ResponseInner",
    "ApiKeyUpdatePostRequest",
    "Apikey",
    "ChangeEmail200Response",
    "ChangeEmailRequest",
    "ChangePassword200Response",
    "ChangePasswordRequest",
    "DeleteUser200Response",
    "DeleteUserCallbackGet200Response",
    "DeleteUserRequest",
    "ForgetPassword200Response",
    "ForgetPasswordRequest",
    "GeneratePasskeyRegistrationOptions200Response",
    "GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection",
    "GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner",
    "GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner",
    "GeneratePasskeyRegistrationOptions200ResponseRp",
    "GeneratePasskeyRegistrationOptions200ResponseUser",
    "GetSession200Response",
    "LinkSocialAccount200Response",
    "LinkSocialAccountRequest",
    "LinkSocialAccountRequestIdToken",
    "ListUserAccounts200ResponseInner",
    "OkGet200Response",
    "OneTapCallbackPost200Response",
    "OneTapCallbackPostRequest",
    "Passkey",
    "PasskeyDeletePasskeyPost200Response",
    "PasskeyDeletePasskeyPostRequest",
    "PasskeyGenerateAuthenticateOptions200Response",
    "PasskeyUpdatePasskeyPost200Response",
    "PasskeyUpdatePasskeyPostRequest",
    "PasskeyVerifyAuthenticationRequest",
    "PasskeyVerifyRegistrationRequest",
    "RefreshTokenPost200Response",
    "RefreshTokenPostRequest",
    "ResetPassword200Response",
    "ResetPasswordCallback200Response",
    "ResetPasswordRequest",
    "RevokeOtherSessionsPost200Response",
    "RevokeSessionPost200Response",
    "RevokeSessionPostRequest",
    "RevokeSessionsPost200Response",
    "SendVerificationEmail200Response",
    "SendVerificationEmail400Response",
    "SendVerificationEmailRequest",
    "Session",
    "SignInEmail200Response",
    "SignInEmailRequest",
    "SignOut200Response",
    "SignUpWithEmailAndPassword200Response",
    "SignUpWithEmailAndPassword200ResponseUser",
    "SignUpWithEmailAndPasswordRequest",
    "SocialSignIn200Response",
    "SocialSignIn400Response",
    "SocialSignIn403Response",
    "SocialSignInRequest",
    "SocialSignInRequestIdToken",
    "TwoFactor",
    "TwoFactorEnablePost200Response",
    "TwoFactorEnablePostRequest",
    "TwoFactorGenerateBackupCodesPost200Response",
    "TwoFactorGenerateBackupCodesPostRequest",
    "TwoFactorGetTotpUriPost200Response",
    "TwoFactorGetTotpUriPostRequest",
    "TwoFactorVerifyBackupCodePost200Response",
    "TwoFactorVerifyBackupCodePost200ResponseSession",
    "TwoFactorVerifyBackupCodePost200ResponseUser",
    "TwoFactorVerifyBackupCodePostRequest",
    "TwoFactorVerifyOtpPost200Response",
    "TwoFactorVerifyOtpPost200ResponseUser",
    "TwoFactorVerifyOtpPostRequest",
    "TwoFactorVerifyTotpPostRequest",
    "UnlinkAccountPostRequest",
    "UpdateUser200Response",
    "UpdateUserRequest",
    "User",
    "Verification",
    "VerifyEmailGet200Response",
]

# import apis into sdk package
from better_auth.api.admin_api import AdminApi as AdminApi
from better_auth.api.api_key_api import ApiKeyApi as ApiKeyApi
from better_auth.api.default_api import DefaultApi as DefaultApi
from better_auth.api.one_tap_api import OneTapApi as OneTapApi
from better_auth.api.passkey_api import PasskeyApi as PasskeyApi
from better_auth.api.stripe_api import StripeApi as StripeApi
from better_auth.api.two_factor_api import TwoFactorApi as TwoFactorApi

# import ApiClient
from better_auth.api_response import ApiResponse as ApiResponse
from better_auth.api_client import ApiClient as ApiClient
from better_auth.configuration import Configuration as Configuration
from better_auth.exceptions import OpenApiException as OpenApiException
from better_auth.exceptions import ApiTypeError as ApiTypeError
from better_auth.exceptions import ApiValueError as ApiValueError
from better_auth.exceptions import ApiKeyError as ApiKeyError
from better_auth.exceptions import ApiAttributeError as ApiAttributeError
from better_auth.exceptions import ApiException as ApiException

# import models into sdk package
from better_auth.models.account import Account as Account
from better_auth.models.account_info_get200_response import AccountInfoGet200Response as AccountInfoGet200Response
from better_auth.models.account_info_get200_response_user import AccountInfoGet200ResponseUser as AccountInfoGet200ResponseUser
from better_auth.models.admin_ban_user_request import AdminBanUserRequest as AdminBanUserRequest
from better_auth.models.admin_create_user_request import AdminCreateUserRequest as AdminCreateUserRequest
from better_auth.models.admin_has_permission200_response import AdminHasPermission200Response as AdminHasPermission200Response
from better_auth.models.admin_has_permission_request import AdminHasPermissionRequest as AdminHasPermissionRequest
from better_auth.models.admin_list_user_sessions200_response import AdminListUserSessions200Response as AdminListUserSessions200Response
from better_auth.models.admin_list_user_sessions_request import AdminListUserSessionsRequest as AdminListUserSessionsRequest
from better_auth.models.admin_list_users200_response import AdminListUsers200Response as AdminListUsers200Response
from better_auth.models.admin_revoke_user_session_request import AdminRevokeUserSessionRequest as AdminRevokeUserSessionRequest
from better_auth.models.admin_set_user_password_request import AdminSetUserPasswordRequest as AdminSetUserPasswordRequest
from better_auth.models.admin_set_user_role_request import AdminSetUserRoleRequest as AdminSetUserRoleRequest
from better_auth.models.admin_update_user_request import AdminUpdateUserRequest as AdminUpdateUserRequest
from better_auth.models.api_key_create_post200_response import ApiKeyCreatePost200Response as ApiKeyCreatePost200Response
from better_auth.models.api_key_create_post_request import ApiKeyCreatePostRequest as ApiKeyCreatePostRequest
from better_auth.models.api_key_delete_post200_response import ApiKeyDeletePost200Response as ApiKeyDeletePost200Response
from better_auth.models.api_key_delete_post_request import ApiKeyDeletePostRequest as ApiKeyDeletePostRequest
from better_auth.models.api_key_get_get200_response import ApiKeyGetGet200Response as ApiKeyGetGet200Response
from better_auth.models.api_key_list_get200_response_inner import ApiKeyListGet200ResponseInner as ApiKeyListGet200ResponseInner
from better_auth.models.api_key_update_post_request import ApiKeyUpdatePostRequest as ApiKeyUpdatePostRequest
from better_auth.models.apikey import Apikey as Apikey
from better_auth.models.change_email200_response import ChangeEmail200Response as ChangeEmail200Response
from better_auth.models.change_email_request import ChangeEmailRequest as ChangeEmailRequest
from better_auth.models.change_password200_response import ChangePassword200Response as ChangePassword200Response
from better_auth.models.change_password_request import ChangePasswordRequest as ChangePasswordRequest
from better_auth.models.delete_user200_response import DeleteUser200Response as DeleteUser200Response
from better_auth.models.delete_user_callback_get200_response import DeleteUserCallbackGet200Response as DeleteUserCallbackGet200Response
from better_auth.models.delete_user_request import DeleteUserRequest as DeleteUserRequest
from better_auth.models.forget_password200_response import ForgetPassword200Response as ForgetPassword200Response
from better_auth.models.forget_password_request import ForgetPasswordRequest as ForgetPasswordRequest
from better_auth.models.generate_passkey_registration_options200_response import GeneratePasskeyRegistrationOptions200Response as GeneratePasskeyRegistrationOptions200Response
from better_auth.models.generate_passkey_registration_options200_response_authenticator_selection import GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection as GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection
from better_auth.models.generate_passkey_registration_options200_response_exclude_credentials_inner import GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner as GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner
from better_auth.models.generate_passkey_registration_options200_response_pub_key_cred_params_inner import GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner as GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner
from better_auth.models.generate_passkey_registration_options200_response_rp import GeneratePasskeyRegistrationOptions200ResponseRp as GeneratePasskeyRegistrationOptions200ResponseRp
from better_auth.models.generate_passkey_registration_options200_response_user import GeneratePasskeyRegistrationOptions200ResponseUser as GeneratePasskeyRegistrationOptions200ResponseUser
from better_auth.models.get_session200_response import GetSession200Response as GetSession200Response
from better_auth.models.link_social_account200_response import LinkSocialAccount200Response as LinkSocialAccount200Response
from better_auth.models.link_social_account_request import LinkSocialAccountRequest as LinkSocialAccountRequest
from better_auth.models.link_social_account_request_id_token import LinkSocialAccountRequestIdToken as LinkSocialAccountRequestIdToken
from better_auth.models.list_user_accounts200_response_inner import ListUserAccounts200ResponseInner as ListUserAccounts200ResponseInner
from better_auth.models.ok_get200_response import OkGet200Response as OkGet200Response
from better_auth.models.one_tap_callback_post200_response import OneTapCallbackPost200Response as OneTapCallbackPost200Response
from better_auth.models.one_tap_callback_post_request import OneTapCallbackPostRequest as OneTapCallbackPostRequest
from better_auth.models.passkey import Passkey as Passkey
from better_auth.models.passkey_delete_passkey_post200_response import PasskeyDeletePasskeyPost200Response as PasskeyDeletePasskeyPost200Response
from better_auth.models.passkey_delete_passkey_post_request import PasskeyDeletePasskeyPostRequest as PasskeyDeletePasskeyPostRequest
from better_auth.models.passkey_generate_authenticate_options200_response import PasskeyGenerateAuthenticateOptions200Response as PasskeyGenerateAuthenticateOptions200Response
from better_auth.models.passkey_update_passkey_post200_response import PasskeyUpdatePasskeyPost200Response as PasskeyUpdatePasskeyPost200Response
from better_auth.models.passkey_update_passkey_post_request import PasskeyUpdatePasskeyPostRequest as PasskeyUpdatePasskeyPostRequest
from better_auth.models.passkey_verify_authentication_request import PasskeyVerifyAuthenticationRequest as PasskeyVerifyAuthenticationRequest
from better_auth.models.passkey_verify_registration_request import PasskeyVerifyRegistrationRequest as PasskeyVerifyRegistrationRequest
from better_auth.models.refresh_token_post200_response import RefreshTokenPost200Response as RefreshTokenPost200Response
from better_auth.models.refresh_token_post_request import RefreshTokenPostRequest as RefreshTokenPostRequest
from better_auth.models.reset_password200_response import ResetPassword200Response as ResetPassword200Response
from better_auth.models.reset_password_callback200_response import ResetPasswordCallback200Response as ResetPasswordCallback200Response
from better_auth.models.reset_password_request import ResetPasswordRequest as ResetPasswordRequest
from better_auth.models.revoke_other_sessions_post200_response import RevokeOtherSessionsPost200Response as RevokeOtherSessionsPost200Response
from better_auth.models.revoke_session_post200_response import RevokeSessionPost200Response as RevokeSessionPost200Response
from better_auth.models.revoke_session_post_request import RevokeSessionPostRequest as RevokeSessionPostRequest
from better_auth.models.revoke_sessions_post200_response import RevokeSessionsPost200Response as RevokeSessionsPost200Response
from better_auth.models.send_verification_email200_response import SendVerificationEmail200Response as SendVerificationEmail200Response
from better_auth.models.send_verification_email400_response import SendVerificationEmail400Response as SendVerificationEmail400Response
from better_auth.models.send_verification_email_request import SendVerificationEmailRequest as SendVerificationEmailRequest
from better_auth.models.session import Session as Session
from better_auth.models.sign_in_email200_response import SignInEmail200Response as SignInEmail200Response
from better_auth.models.sign_in_email_request import SignInEmailRequest as SignInEmailRequest
from better_auth.models.sign_out200_response import SignOut200Response as SignOut200Response
from better_auth.models.sign_up_with_email_and_password200_response import SignUpWithEmailAndPassword200Response as SignUpWithEmailAndPassword200Response
from better_auth.models.sign_up_with_email_and_password200_response_user import SignUpWithEmailAndPassword200ResponseUser as SignUpWithEmailAndPassword200ResponseUser
from better_auth.models.sign_up_with_email_and_password_request import SignUpWithEmailAndPasswordRequest as SignUpWithEmailAndPasswordRequest
from better_auth.models.social_sign_in200_response import SocialSignIn200Response as SocialSignIn200Response
from better_auth.models.social_sign_in400_response import SocialSignIn400Response as SocialSignIn400Response
from better_auth.models.social_sign_in403_response import SocialSignIn403Response as SocialSignIn403Response
from better_auth.models.social_sign_in_request import SocialSignInRequest as SocialSignInRequest
from better_auth.models.social_sign_in_request_id_token import SocialSignInRequestIdToken as SocialSignInRequestIdToken
from better_auth.models.two_factor import TwoFactor as TwoFactor
from better_auth.models.two_factor_enable_post200_response import TwoFactorEnablePost200Response as TwoFactorEnablePost200Response
from better_auth.models.two_factor_enable_post_request import TwoFactorEnablePostRequest as TwoFactorEnablePostRequest
from better_auth.models.two_factor_generate_backup_codes_post200_response import TwoFactorGenerateBackupCodesPost200Response as TwoFactorGenerateBackupCodesPost200Response
from better_auth.models.two_factor_generate_backup_codes_post_request import TwoFactorGenerateBackupCodesPostRequest as TwoFactorGenerateBackupCodesPostRequest
from better_auth.models.two_factor_get_totp_uri_post200_response import TwoFactorGetTotpUriPost200Response as TwoFactorGetTotpUriPost200Response
from better_auth.models.two_factor_get_totp_uri_post_request import TwoFactorGetTotpUriPostRequest as TwoFactorGetTotpUriPostRequest
from better_auth.models.two_factor_verify_backup_code_post200_response import TwoFactorVerifyBackupCodePost200Response as TwoFactorVerifyBackupCodePost200Response
from better_auth.models.two_factor_verify_backup_code_post200_response_session import TwoFactorVerifyBackupCodePost200ResponseSession as TwoFactorVerifyBackupCodePost200ResponseSession
from better_auth.models.two_factor_verify_backup_code_post200_response_user import TwoFactorVerifyBackupCodePost200ResponseUser as TwoFactorVerifyBackupCodePost200ResponseUser
from better_auth.models.two_factor_verify_backup_code_post_request import TwoFactorVerifyBackupCodePostRequest as TwoFactorVerifyBackupCodePostRequest
from better_auth.models.two_factor_verify_otp_post200_response import TwoFactorVerifyOtpPost200Response as TwoFactorVerifyOtpPost200Response
from better_auth.models.two_factor_verify_otp_post200_response_user import TwoFactorVerifyOtpPost200ResponseUser as TwoFactorVerifyOtpPost200ResponseUser
from better_auth.models.two_factor_verify_otp_post_request import TwoFactorVerifyOtpPostRequest as TwoFactorVerifyOtpPostRequest
from better_auth.models.two_factor_verify_totp_post_request import TwoFactorVerifyTotpPostRequest as TwoFactorVerifyTotpPostRequest
from better_auth.models.unlink_account_post_request import UnlinkAccountPostRequest as UnlinkAccountPostRequest
from better_auth.models.update_user200_response import UpdateUser200Response as UpdateUser200Response
from better_auth.models.update_user_request import UpdateUserRequest as UpdateUserRequest
from better_auth.models.user import User as User
from better_auth.models.verification import Verification as Verification
from better_auth.models.verify_email_get200_response import VerifyEmailGet200Response as VerifyEmailGet200Response

