# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.admin_create_user_request import AdminCreateUserRequest

class TestAdminCreateUserRequest(unittest.TestCase):
    """AdminCreateUserRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminCreateUserRequest:
        """Test AdminCreateUserRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminCreateUserRequest`
        """
        model = AdminCreateUserRequest()
        if include_optional:
            return AdminCreateUserRequest(
                email = '',
                password = '',
                name = '',
                role = '',
                data = ''
            )
        else:
            return AdminCreateUserRequest(
                email = '',
                password = '',
                name = '',
        )
        """

    def testAdminCreateUserRequest(self):
        """Test AdminCreateUserRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
