# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.admin_list_users200_response import AdminListUsers200Response

class TestAdminListUsers200Response(unittest.TestCase):
    """AdminListUsers200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminListUsers200Response:
        """Test AdminListUsers200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminListUsers200Response`
        """
        model = AdminListUsers200Response()
        if include_optional:
            return AdminListUsers200Response(
                users = [
                    better_auth.models.user.User(
                        id = '', 
                        name = '', 
                        email = '', 
                        email_verified = True, 
                        image = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        two_factor_enabled = True, 
                        role = '', 
                        banned = True, 
                        ban_reason = '', 
                        ban_expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 1.337,
                limit = 1.337,
                offset = 1.337
            )
        else:
            return AdminListUsers200Response(
                users = [
                    better_auth.models.user.User(
                        id = '', 
                        name = '', 
                        email = '', 
                        email_verified = True, 
                        image = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        two_factor_enabled = True, 
                        role = '', 
                        banned = True, 
                        ban_reason = '', 
                        ban_expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 1.337,
        )
        """

    def testAdminListUsers200Response(self):
        """Test AdminListUsers200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
