# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.stripe_api import StripeApi


class TestStripeApi(unittest.TestCase):
    """StripeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StripeApi()

    def tearDown(self) -> None:
        pass

    def test_handle_stripe_webhook(self) -> None:
        """Test case for handle_stripe_webhook

        """
        pass


if __name__ == '__main__':
    unittest.main()
