# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.admin_api import AdminApi


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminApi()

    def tearDown(self) -> None:
        pass

    def test_admin_ban_user(self) -> None:
        """Test case for admin_ban_user

        """
        pass

    def test_admin_create_user(self) -> None:
        """Test case for admin_create_user

        """
        pass

    def test_admin_get_user(self) -> None:
        """Test case for admin_get_user

        """
        pass

    def test_admin_has_permission(self) -> None:
        """Test case for admin_has_permission

        """
        pass

    def test_admin_impersonate_user(self) -> None:
        """Test case for admin_impersonate_user

        """
        pass

    def test_admin_list_user_sessions(self) -> None:
        """Test case for admin_list_user_sessions

        """
        pass

    def test_admin_list_users(self) -> None:
        """Test case for admin_list_users

        """
        pass

    def test_admin_remove_user(self) -> None:
        """Test case for admin_remove_user

        """
        pass

    def test_admin_revoke_user_session(self) -> None:
        """Test case for admin_revoke_user_session

        """
        pass

    def test_admin_revoke_user_sessions(self) -> None:
        """Test case for admin_revoke_user_sessions

        """
        pass

    def test_admin_set_user_password(self) -> None:
        """Test case for admin_set_user_password

        """
        pass

    def test_admin_set_user_role(self) -> None:
        """Test case for admin_set_user_role

        """
        pass

    def test_admin_stop_impersonating(self) -> None:
        """Test case for admin_stop_impersonating

        """
        pass

    def test_admin_unban_user(self) -> None:
        """Test case for admin_unban_user

        """
        pass

    def test_admin_update_user(self) -> None:
        """Test case for admin_update_user

        """
        pass


if __name__ == '__main__':
    unittest.main()
