# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.two_factor_api import TwoFactorApi


class TestTwoFactorApi(unittest.TestCase):
    """TwoFactorApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TwoFactorApi()

    def tearDown(self) -> None:
        pass

    def test_two_factor_disable_post(self) -> None:
        """Test case for two_factor_disable_post

        """
        pass

    def test_two_factor_enable_post(self) -> None:
        """Test case for two_factor_enable_post

        """
        pass

    def test_two_factor_generate_backup_codes_post(self) -> None:
        """Test case for two_factor_generate_backup_codes_post

        """
        pass

    def test_two_factor_get_totp_uri_post(self) -> None:
        """Test case for two_factor_get_totp_uri_post

        """
        pass

    def test_two_factor_send_otp_post(self) -> None:
        """Test case for two_factor_send_otp_post

        """
        pass

    def test_two_factor_verify_backup_code_post(self) -> None:
        """Test case for two_factor_verify_backup_code_post

        """
        pass

    def test_two_factor_verify_otp_post(self) -> None:
        """Test case for two_factor_verify_otp_post

        """
        pass

    def test_two_factor_verify_totp_post(self) -> None:
        """Test case for two_factor_verify_totp_post

        """
        pass


if __name__ == '__main__':
    unittest.main()
